//
//  User.swift
//  App
//
//  Created by Arnaud on 21.07.18.
//

import FluentSQLite
import Vapor
import Authentication

final class User: SQLiteModel, PasswordAuthenticatable {
    
    var id: Int?
    
    static var usernameKey: WritableKeyPath<User, String> = \.username
    static var passwordKey: WritableKeyPath<User, String> = \.password

    var username: String
    var email: String
    var password: String

    /// Creates a new user.
    init(id: Int? = nil, username: String, password: String, email: String) {
        self.id = id
        self.username = username
        self.password = password
        self.email = email
    }
}

extension User: SQLiteMigration { }
extension User: Content { }
extension User: Parameter { }

enum Privilege:Int {
    case User
    case Admin
}
enum Gender:Int {
    case Male
    case Female
    case Undefined
}

final class UserRegister: Content {
    var username: String
    var password: String
    var passwordBis: String
    var email: String
    var firstName: String
    var lastName: String
    var birthDate: String
    var gender: Int
    
    init(username: String, password: String, passwordBis: String, email: String, firstName: String, lastName: String, birthDate: String, gender: Int) {
        self.username = username
        self.password = password
        self.passwordBis = passwordBis
        self.email = email
        self.firstName = firstName
        self.lastName = lastName
        self.birthDate = birthDate
        self.gender = gender
    }
}

final class UserLogin: Content {
    var username: String
    var password: String
    
    init(username: String, password: String) {
        self.username = username
        self.password = password
    }
}
