//
//  UsersViewController.swift
//  App
//
//  Created by Arnaud on 28.07.18.
//

import Vapor
import Crypto
import Authentication

class UsersViewController: RouteCollection {
    
    func boot(router: Router) throws {
        let users = router.grouped("users")
        
        users.get("login", use: login)                                      // GET login
        users.post(UserLogin.self, at: "login", use: loginPost)             // POST login
    }
    
    func login(_ req: Request) throws -> Future<View> {
        guard try req.session()["userId"] == nil else { throw Abort(.badRequest) }
        return try req.view().render("users/login")
    }
    
    func loginPost(_ req: Request, attemptUser: UserLogin) throws -> Future<Response> {
        guard attemptUser.password.count > 0 else { throw Abort(.badRequest) }
        guard attemptUser.username.count > 0 else { throw Abort(.badRequest) }
        return User.query(on: req).filter(\.username == attemptUser.username).first().flatMap() { existingUser in
            
            return req.future(req.redirect(to: "/users/login"))
        }
    }
}
